@@ -25,7 +25,7 @@ class PathProxy:
         return PathProxy.getProjectDir(projectname) + classname + "\\"
         
     def getModelDir(projectname):
-        return os.path.join(PathProxy.getProjectDir(projectname) , "model\\")
+        return os.path.join(PathProxy.getProjectDir(projectname) , "models\\")
     
     def getModelTagDir(projectname,tag):
         return os.path.join(PathProxy.getModelDir(projectname) , tag)
@@ -42,8 +42,8 @@ class PathProxy:
     def getTrainLogPath(projectname,tag):
         return os.path.join(PathProxy.getModelTagDir(projectname,tag) , 'tpv.csv')
     
-    def getModelParamPath(projectname,tag):
-        return os.path.join(PathProxy.getSaverPath(projectname,tag) , "ckpt","save.ckpt")
+    def getSaverPath(projectname,tag):
+        return os.path.join(PathProxy.getModelTagDir(projectname,tag) , "ckpt","save.ckpt")
     
     """
     method here
